==> anyconnect-macos-4.10.06090-vpnapi.tar.gz: doc/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "AnyConnect Secure Mobility Client", "index.html", [
    [ "AnyConnect VPN Client C++ API", "index.html", [
      [ "Preface", "index.html#pref_sec", null ],
      [ "Introduction", "index.html#intro_sec", null ]
    ] ],
    [ "Building an AnyConnect client", "build_sec.html", [
      [ "Windows", "build_sec.html#win_sec", [
        [ "Visual Studio", "build_sec.html#vs_sec", null ],
        [ "AnyConnect VpnApi dll", "build_sec.html#dll_sec", null ],
        [ "Debugging", "build_sec.html#vs_debug", null ],
        [ "Wide Character Support", "build_sec.html#wide_sec", null ]
      ] ],
      [ "macOS and Linux", "build_sec.html#mac_sec", null ]
    ] ],
    [ "Basic Capabilities", "basic_cap_pag.html", [
      [ "Managing the VPN", "basic_cap_pag.html#bas_sec", [
        [ "Connect", "basic_cap_pag.html#connect_sub", null ],
        [ "Disconnect", "basic_cap_pag.html#disconnect_sub", null ],
        [ "Statistics", "basic_cap_pag.html#stats_sub", null ],
        [ "State Changes", "basic_cap_pag.html#state_sub", null ],
        [ "Notices", "basic_cap_pag.html#notices_sub", null ]
      ] ],
      [ "Activating the API", "basic_cap_pag.html#act_sec", [
        [ "Attach Method", "basic_cap_pag.html#attach_sub", null ],
        [ "Detach Method", "basic_cap_pag.html#detach_sub", null ],
        [ "ServiceReadyCB Method", "basic_cap_pag.html#svc_rdy_sub", null ]
      ] ],
      [ "Certificate Selection", "basic_cap_pag.html#cert_sel_sec", null ],
      [ "Certificate Import", "basic_cap_pag.html#cert_imp_sec", null ],
      [ "CSD Integration", "basic_cap_pag.html#csd_sec", null ]
    ] ],
    [ "The API Interface", "api_files_sec.html", "api_files_sec" ],
    [ "Advanced Topics", "adv_page.html", [
      [ "GUI implementations", "adv_page.html#gui_sub", [
        [ "Window Management Hints", "adv_page.html#wm_sub", null ]
      ] ],
      [ "Program Signing", "adv_page.html#sign_sub", [
        [ "GUI Restart Following AnyConnect Upgrade", "adv_page.html#res_int_sub", null ],
        [ "Cisco Secure Desktop Integration", "adv_page.html#csd_int_sub", null ],
        [ "Start Before Logon", "adv_page.html#sbl_int_sub", null ]
      ] ],
      [ "Program Naming", "adv_page.html#name_sub", null ],
      [ "Program Arguments", "adv_page.html#args_sub", [
        [ "Start Before Logon", "adv_page.html#sbl_sub", null ],
        [ "Cisco Secure Desktop", "adv_page.html#csd_sub", null ],
        [ "Web Launch", "adv_page.html#web_sub", null ]
      ] ],
      [ "Localization", "adv_page.html#l10n_sub", null ],
      [ "Proxy Support", "adv_page.html#prox_sub", null ],
      [ "Examples", "adv_page.html#example_sec", null ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_c_l_i_client_impl_8cpp.html",
"basic_cap_pag.html#act_sec",
"class_connect_prompt_info_base.html#a91ec8187f47b23dfe38426bef9904fc7"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> anyconnect-macos-4.10.08029-vpnapi.tar.gz: doc/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "AnyConnect Secure Mobility Client", "index.html", [
    [ "AnyConnect VPN Client C++ API", "index.html", [
      [ "Preface", "index.html#pref_sec", null ],
      [ "Introduction", "index.html#intro_sec", null ]
    ] ],
    [ "Building an AnyConnect client", "build_sec.html", [
      [ "Windows", "build_sec.html#win_sec", [
        [ "Visual Studio", "build_sec.html#vs_sec", null ],
        [ "AnyConnect VpnApi dll", "build_sec.html#dll_sec", null ],
        [ "Debugging", "build_sec.html#vs_debug", null ],
        [ "Wide Character Support", "build_sec.html#wide_sec", null ]
      ] ],
      [ "macOS and Linux", "build_sec.html#mac_sec", null ]
    ] ],
    [ "Basic Capabilities", "basic_cap_pag.html", [
      [ "Managing the VPN", "basic_cap_pag.html#bas_sec", [
        [ "Connect", "basic_cap_pag.html#connect_sub", null ],
        [ "Disconnect", "basic_cap_pag.html#disconnect_sub", null ],
        [ "Statistics", "basic_cap_pag.html#stats_sub", null ],
        [ "State Changes", "basic_cap_pag.html#state_sub", null ],
        [ "Notices", "basic_cap_pag.html#notices_sub", null ]
      ] ],
      [ "Activating the API", "basic_cap_pag.html#act_sec", [
        [ "Attach Method", "basic_cap_pag.html#attach_sub", null ],
        [ "Detach Method", "basic_cap_pag.html#detach_sub", null ],
        [ "ServiceReadyCB Method", "basic_cap_pag.html#svc_rdy_sub", null ]
      ] ],
      [ "Certificate Selection", "basic_cap_pag.html#cert_sel_sec", null ],
      [ "Certificate Import", "basic_cap_pag.html#cert_imp_sec", null ],
      [ "CSD Integration", "basic_cap_pag.html#csd_sec", null ]
    ] ],
    [ "The API Interface", "api_files_sec.html", "api_files_sec" ],
    [ "Advanced Topics", "adv_page.html", [
      [ "GUI implementations", "adv_page.html#gui_sub", [
        [ "Window Management Hints", "adv_page.html#wm_sub", null ]
      ] ],
      [ "Program Signing", "adv_page.html#sign_sub", [
        [ "GUI Restart Following AnyConnect Upgrade", "adv_page.html#res_int_sub", null ],
        [ "Cisco Secure Desktop Integration", "adv_page.html#csd_int_sub", null ],
        [ "Start Before Logon", "adv_page.html#sbl_int_sub", null ]
      ] ],
      [ "Program Naming", "adv_page.html#name_sub", null ],
      [ "Program Arguments", "adv_page.html#args_sub", [
        [ "Start Before Logon", "adv_page.html#sbl_sub", null ],
        [ "Cisco Secure Desktop", "adv_page.html#csd_sub", null ],
        [ "Web Launch", "adv_page.html#web_sub", null ]
      ] ],
      [ "Localization", "adv_page.html#l10n_sub", null ],
      [ "Proxy Support", "adv_page.html#prox_sub", null ],
      [ "Examples", "adv_page.html#example_sec", null ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_c_l_i_client_impl_8cpp.html",
"basic_cap_pag.html",
"class_connect_prompt_info_base.html#a6e89c0acb559d27be57430c4ed478d32"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
